| Home | Libraries | People | FAQ | More

### is_base_of

    template <class Base, class Derived>
    struct is_base_of : public true_type-or-false_type {};

Inherits: If Base is base class of type Derived or if both types are the same class type then inherits from true_type, otherwise inherits from false_type.

This template will detect non-public base classes, and ambiguous base classes. It also detects indirect base classes - which is to say is_base_of<B, D> inherits from true_type if B is located anywhere in the inheritance tree of D.

Note that `is_base_of<X,X>` will inherit from true_type if X is a class type. This is a change in behaviour from Boost-1.39.0 in order to track the emerging C++0x standard.

Types `Base` and `Derived` must not be incomplete types.

C++ Standard Reference: 10.

Header: `#include <boost/type_traits/is_base_of.hpp>` or `#include <boost/type_traits.hpp>`

Compiler Compatibility: If the compiler does not support partial-specialization of class templates, then this template can not be used with function types. There are some older compilers which will produce compiler errors if `Base` is a private base class of `Derived`, or if `Base` is an ambiguous base of `Derived`. These compilers include Borland C++, older versions of Sun Forte C++, Digital Mars C++, and older versions of EDG based compilers.

Examples:

> Given: `class Base{}; class Derived : public Base{};`

> `is_base_of<Base, Derived>` inherits from `true_type`.

> `is_base_of<Base, Derived>::type` is the type `true_type`.

> `is_base_of<Base, Derived>::value` is an integral constant expression that evaluates to true.

> `is_base_of<Base, Base>::value` is an integral constant expression that evaluates to true: a class is regarded as it's own base.

> `is_base_of<T, T>::value_type` is the type `bool`.